@@ -4,20 +4,25 @@ import string
 import errno
 import sys
 from collections import OrderedDict
-
-from selenium import webdriver
+from wire import webdriver
+from pathlib import Path
+#print('Running' if __name__ == '__main__' else 'Importing', Path(__file__).resolve())
+#from selenium import webdriver as cc
 from selenium.common import exceptions
 from selenium.webdriver.common.action_chains import ActionChains
 from selenium.webdriver.common.keys import Keys
-
-
+#Running C:\Users\km\Downloads\wybsel\wybsel\wybsel.py
+#Running C:\Users\km\Downloads\wybsel\wybsel\wire\browser.py
 # TODO : ADD AN ASSERT TEXT OR ELEMENT FUNCTION
 
 
 class Browser:
    
-    def __init__(self, showWindow=True, proxy=None , downloadPath:str=None, arguments=["--disable-dev-shm-usage","--no-sandbox"]):
+    def __init__(self, showWindow=True, proxy=None , binary_location = None, potions = None, headers=None, downloadPath:str=None, arguments=["--disable-dev-shm-usage","--no-sandbox"]):
         options = webdriver.ChromeOptions()
+        if binary_location:
+            options.binary_location = binary_location
+        #options.binary_location = "C:\\Program Files\\Google\\Chrome\\Application\\chrome.exe"
 
         for argument in arguments:
             options.add_argument(argument)
@@ -28,10 +33,10 @@ class Browser:
                 raise FileNotFoundError(errno.ENOENT, os.strerror(errno.ENOENT), absolutePath)
 
             options.add_experimental_option('prefs', {'download.default_directory' : absolutePath})
-
+             
         if proxy is not None and isinstance(proxy, str):
             # Check if '--proxy-server' has not yet been set
-            if not any(arg.starts_with("--proxy-server") for arg in arguments):
+            if not any(arg.startswith("--proxy-server") for arg in arguments):
                 options.add_argument("--proxy-server={}".format(proxy))
 
         if not showWindow and '--headless' not in arguments:
@@ -48,8 +53,12 @@ class Browser:
         driverpath = os.path.join(os.path.split(__file__)[0], 'drivers{0}{1}'.format(os.path.sep, driverfilename))
 
         os.chmod(driverpath, 0o755)
-
-        self.driver = webdriver.Chrome(executable_path=driverpath, options=options)
+        if potions:
+           self.driver = webdriver.Chrome(wire_options=potions, options=options)
+        else:
+            self.driver = webdriver.Chrome(executable_path=driverpath, options=options)
+        if headers:
+            self.driver._client.set_header_overrides(headers= headers)
         self.Key = Keys
         self.errors = []
 
@@ -607,7 +616,11 @@ class Browser:
 
 
 if __name__ == '__main__':
-    aton = Browser()
-    aton.go_to('https://google.com')
-    aton.type("Hello its me ", into="Search")
+    headers= {'Referer':'https://me.myself.and.i'}
+    #bina = "C:\\Program Files\\Google\\Chrome\\Application\\chrome.exe"
+
+
+    aton = Browser(headers=headers) #binary_location = bina)
+    aton.go_to('http://azenv.net')
+    #aton.type("Hello its me ", into="Search")
     aton.press(aton.Key.ENTER)
